Title: [198527] trunk/Source
Revision
198527
Author
[email protected]
Date
2016-03-22 06:47:30 -0700 (Tue, 22 Mar 2016)

Log Message

Source/ThirdParty/ANGLE:
Unreviewed typo fix.

* src/compiler/translator/InfoSink.cpp:
(TInfoSinkBase::prefix): "UNKOWN" => "UNKOWN".

Source/WebCore:
Unreviewed typo fix.

* platform/gtk/LocalizedStringsGtk.cpp:
(WebCore::textTrackAutomaticMenuItemText): "choosen" => "chosen"

Source/WebCore/platform/gtk/po:
Unreviewed typo fix "choosen" => "chosen"

* as.po:
* bg.po:
* ca.po:
* de.po:
* en_GB.po:
* es.po:
* fr.po:
* gl.po:
* gu.po:
* he.po:
* hi.po:
* it.po:
* ja.po:
* kn.po:
* mr.po:
* nl.po:
* or.po:
* pl.po:
* pt_BR.po:
* sl.po:
* sv.po:
* ta.po:
* te.po:
* tr.po:

Source/WebKit2:
Unreviewed typo fixes.

* Shared/linux/WebMemorySamplerLinux.cpp:
(WebKit::WebMemorySampler::sampleWebKit): "Commited" => "Committed"
* UIProcess/API/gtk/WebKitFileChooserRequest.cpp:
(webkit_file_chooser_request_select_files): "choosen" => "chosen"
* UIProcess/API/gtk/WebKitUserMediaPermissionRequest.cpp:
(webkit_user_media_permission_request_class_init): "Wether" => "Whether"

Modified Paths

Diff

Modified: trunk/Source/ThirdParty/ANGLE/ChangeLog (198526 => 198527)


--- trunk/Source/ThirdParty/ANGLE/ChangeLog	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/ThirdParty/ANGLE/ChangeLog	2016-03-22 13:47:30 UTC (rev 198527)
@@ -1,3 +1,10 @@
+2016-03-22  Alberto Garcia  <[email protected]>
+
+        Unreviewed typo fix.
+
+        * src/compiler/translator/InfoSink.cpp:
+        (TInfoSinkBase::prefix): "UNKOWN" => "UNKOWN".
+
 2016-03-20  Dan Bernstein  <[email protected]>
 
         [Mac] Determine TARGET_MAC_OS_X_VERSION_MAJOR from MACOSX_DEPLOYMENT_TARGET rather than from MAC_OS_X_VERSION_MAJOR

Modified: trunk/Source/ThirdParty/ANGLE/src/compiler/translator/InfoSink.cpp (198526 => 198527)


--- trunk/Source/ThirdParty/ANGLE/src/compiler/translator/InfoSink.cpp	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/ThirdParty/ANGLE/src/compiler/translator/InfoSink.cpp	2016-03-22 13:47:30 UTC (rev 198527)
@@ -26,7 +26,7 @@
             sink.append("NOTE: ");
             break;
         default:
-            sink.append("UNKOWN ERROR: ");
+            sink.append("UNKNOWN ERROR: ");
             break;
     }
 }

Modified: trunk/Source/WebCore/ChangeLog (198526 => 198527)


--- trunk/Source/WebCore/ChangeLog	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/ChangeLog	2016-03-22 13:47:30 UTC (rev 198527)
@@ -1,3 +1,10 @@
+2016-03-22  Alberto Garcia  <[email protected]>
+
+        Unreviewed typo fix.
+
+        * platform/gtk/LocalizedStringsGtk.cpp:
+        (WebCore::textTrackAutomaticMenuItemText): "choosen" => "chosen"
+
 2016-03-22  Zan Dobersek  <[email protected]>
 
         [TextureMapper] Destructing TextureMapperLayer should clean up its effect target

Modified: trunk/Source/WebCore/platform/gtk/LocalizedStringsGtk.cpp (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/LocalizedStringsGtk.cpp	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/LocalizedStringsGtk.cpp	2016-03-22 13:47:30 UTC (rev 198527)
@@ -802,7 +802,7 @@
 
 String textTrackAutomaticMenuItemText()
 {
-    return String::fromUTF8(C_("Menu item label for the automatically choosen track", "Auto"));
+    return String::fromUTF8(C_("Menu item label for the automatically chosen track", "Auto"));
 }
 
 String textTrackNoLabelText()

Modified: trunk/Source/WebCore/platform/gtk/po/ChangeLog (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/ChangeLog	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/ChangeLog	2016-03-22 13:47:30 UTC (rev 198527)
@@ -1,3 +1,32 @@
+2016-03-22  Alberto Garcia  <[email protected]>
+
+        Unreviewed typo fix "choosen" => "chosen"
+
+        * as.po:
+        * bg.po:
+        * ca.po:
+        * de.po:
+        * en_GB.po:
+        * es.po:
+        * fr.po:
+        * gl.po:
+        * gu.po:
+        * he.po:
+        * hi.po:
+        * it.po:
+        * ja.po:
+        * kn.po:
+        * mr.po:
+        * nl.po:
+        * or.po:
+        * pl.po:
+        * pt_BR.po:
+        * sl.po:
+        * sv.po:
+        * ta.po:
+        * te.po:
+        * tr.po:
+
 2016-02-22  Piotr Drąg <[email protected]>
 
         [l10n] Updated Polish translation of WebKitGTK+ for 2.12

Modified: trunk/Source/WebCore/platform/gtk/po/as.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/as.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/as.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -589,7 +589,7 @@
 msgstr "অফ"
 
 #: ../LocalizedStringsGtk.cpp:806
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "স্বচালিত"
 

Modified: trunk/Source/WebCore/platform/gtk/po/bg.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/bg.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/bg.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -591,7 +591,7 @@
 msgstr "Изключени"
 
 #: ../LocalizedStringsGtk.cpp:806
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "Автоматично"
 

Modified: trunk/Source/WebCore/platform/gtk/po/ca.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/ca.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/ca.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -597,7 +597,7 @@
 msgstr "Desactivat"
 
 #: ../LocalizedStringsGtk.cpp:806
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "Automàtic"
 

Modified: trunk/Source/WebCore/platform/gtk/po/de.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/de.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/de.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -593,7 +593,7 @@
 msgstr "Aus"
 
 #: ../LocalizedStringsGtk.cpp:795
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "Automatisch"
 

Modified: trunk/Source/WebCore/platform/gtk/po/en_GB.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/en_GB.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/en_GB.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -596,7 +596,7 @@
 msgstr "Off"
 
 #: ../LocalizedStringsGtk.cpp:808
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "Auto"
 

Modified: trunk/Source/WebCore/platform/gtk/po/es.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/es.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/es.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -601,7 +601,7 @@
 msgstr "Desactivados"
 
 #: ../LocalizedStringsGtk.cpp:811
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "Automáticos"
 

Modified: trunk/Source/WebCore/platform/gtk/po/fr.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/fr.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/fr.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -607,7 +607,7 @@
 msgstr ""
 
 #: ../LocalizedStringsGtk.cpp:795
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr ""
 

Modified: trunk/Source/WebCore/platform/gtk/po/gl.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/gl.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/gl.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -590,7 +590,7 @@
 msgstr "Apagado"
 
 #: ../LocalizedStringsGtk.cpp:808
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "Automático"
 

Modified: trunk/Source/WebCore/platform/gtk/po/gu.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/gu.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/gu.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -591,7 +591,7 @@
 msgstr "બંધ"
 
 #: ../LocalizedStringsGtk.cpp:806
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "સ્વયં"
 

Modified: trunk/Source/WebCore/platform/gtk/po/he.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/he.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/he.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -591,7 +591,7 @@
 msgstr "כבוי"
 
 #: ../LocalizedStringsGtk.cpp:806
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "אוטומטי"
 

Modified: trunk/Source/WebCore/platform/gtk/po/hi.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/hi.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/hi.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -594,7 +594,7 @@
 msgstr "बंद"
 
 #: ../LocalizedStringsGtk.cpp:806
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "स्वतः"
 

Modified: trunk/Source/WebCore/platform/gtk/po/it.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/it.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/it.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -622,7 +622,7 @@
 msgstr "Off"
 
 #: ../LocalizedStringsGtk.cpp:795
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "Auto"
 

Modified: trunk/Source/WebCore/platform/gtk/po/ja.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/ja.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/ja.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -588,7 +588,7 @@
 msgstr "オフ"
 
 #: ../LocalizedStringsGtk.cpp:808
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "自動"
 

Modified: trunk/Source/WebCore/platform/gtk/po/kn.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/kn.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/kn.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -589,7 +589,7 @@
 msgstr "ಆಫ್"
 
 #: ../LocalizedStringsGtk.cpp:806
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "ಸ್ವಯಂ"
 

Modified: trunk/Source/WebCore/platform/gtk/po/mr.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/mr.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/mr.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -590,7 +590,7 @@
 msgstr "बंद करा"
 
 #: ../LocalizedStringsGtk.cpp:806
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "स्व"
 

Modified: trunk/Source/WebCore/platform/gtk/po/nl.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/nl.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/nl.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -595,7 +595,7 @@
 msgstr "Uit"
 
 #: ../LocalizedStringsGtk.cpp:808
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "Auto"
 

Modified: trunk/Source/WebCore/platform/gtk/po/or.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/or.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/or.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -593,7 +593,7 @@
 msgstr "ଅଫ"
 
 #: ../LocalizedStringsGtk.cpp:806
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "ସ୍ୱୟଂଚାଳିତ"
 

Modified: trunk/Source/WebCore/platform/gtk/po/pl.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/pl.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/pl.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -595,7 +595,7 @@
 msgstr "Wyłączone"
 
 #: ../LocalizedStringsGtk.cpp:795
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "Automatyczne"
 

Modified: trunk/Source/WebCore/platform/gtk/po/pt_BR.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/pt_BR.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/pt_BR.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -591,7 +591,7 @@
 msgstr "Desligado"
 
 #: ../LocalizedStringsGtk.cpp:808
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "Automático"
 

Modified: trunk/Source/WebCore/platform/gtk/po/sl.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/sl.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/sl.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -603,7 +603,7 @@
 msgstr "Izključeno"
 
 #: ../LocalizedStringsGtk.cpp:808
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "Samodejno"
 

Modified: trunk/Source/WebCore/platform/gtk/po/sv.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/sv.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/sv.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -589,7 +589,7 @@
 msgstr "Av"
 
 #: ../LocalizedStringsGtk.cpp:806
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "Auto"
 

Modified: trunk/Source/WebCore/platform/gtk/po/ta.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/ta.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/ta.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -590,7 +590,7 @@
 msgstr "அணை"
 
 #: ../LocalizedStringsGtk.cpp:806
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "தானியக்கம்"
 

Modified: trunk/Source/WebCore/platform/gtk/po/te.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/te.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/te.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -593,7 +593,7 @@
 msgstr "ఆఫ్"
 
 #: ../LocalizedStringsGtk.cpp:806
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "స్వయం"
 

Modified: trunk/Source/WebCore/platform/gtk/po/tr.po (198526 => 198527)


--- trunk/Source/WebCore/platform/gtk/po/tr.po	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebCore/platform/gtk/po/tr.po	2016-03-22 13:47:30 UTC (rev 198527)
@@ -594,7 +594,7 @@
 msgstr "Kapalı"
 
 #: ../LocalizedStringsGtk.cpp:795
-msgctxt "Menu item label for the automatically choosen track"
+msgctxt "Menu item label for the automatically chosen track"
 msgid "Auto"
 msgstr "Otomatik"
 

Modified: trunk/Source/WebKit2/ChangeLog (198526 => 198527)


--- trunk/Source/WebKit2/ChangeLog	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebKit2/ChangeLog	2016-03-22 13:47:30 UTC (rev 198527)
@@ -1,3 +1,14 @@
+2016-03-22  Alberto Garcia  <[email protected]>
+
+        Unreviewed typo fixes.
+
+        * Shared/linux/WebMemorySamplerLinux.cpp:
+        (WebKit::WebMemorySampler::sampleWebKit): "Commited" => "Committed"
+        * UIProcess/API/gtk/WebKitFileChooserRequest.cpp:
+        (webkit_file_chooser_request_select_files): "choosen" => "chosen"
+        * UIProcess/API/gtk/WebKitUserMediaPermissionRequest.cpp:
+        (webkit_user_media_permission_request_class_init): "Wether" => "Whether"
+
 2016-03-22  Carlos Garcia Campos  <[email protected]>
 
         Remove unused display and scroll view methods from PageClient and WebPageProxy

Modified: trunk/Source/WebKit2/Shared/linux/WebMemorySamplerLinux.cpp (198526 => 198527)


--- trunk/Source/WebKit2/Shared/linux/WebMemorySamplerLinux.cpp	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebKit2/Shared/linux/WebMemorySamplerLinux.cpp	2016-03-22 13:47:30 UTC (rev 198527)
@@ -162,7 +162,7 @@
     totalBytesCommitted += globalMemoryStats.stackBytes + globalMemoryStats.JITBytes;
 
     appendKeyValuePair(webKitMemoryStats, ASCIILiteral("_javascript_ Heap In Use"), jscHeapBytesInUse);
-    appendKeyValuePair(webKitMemoryStats, ASCIILiteral("_javascript_ Heap Commited Memory"), jscHeapBytesCommitted);
+    appendKeyValuePair(webKitMemoryStats, ASCIILiteral("_javascript_ Heap Committed Memory"), jscHeapBytesCommitted);
     
     appendKeyValuePair(webKitMemoryStats, ASCIILiteral("_javascript_ Stack Bytes"), globalMemoryStats.stackBytes);
     appendKeyValuePair(webKitMemoryStats, ASCIILiteral("_javascript_ JIT Bytes"), globalMemoryStats.JITBytes);

Modified: trunk/Source/WebKit2/UIProcess/API/gtk/WebKitFileChooserRequest.cpp (198526 => 198527)


--- trunk/Source/WebKit2/UIProcess/API/gtk/WebKitFileChooserRequest.cpp	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebKit2/UIProcess/API/gtk/WebKitFileChooserRequest.cpp	2016-03-22 13:47:30 UTC (rev 198527)
@@ -299,7 +299,7 @@
     g_return_if_fail(files);
 
     GRefPtr<GPtrArray> selectedFiles = adoptGRef(g_ptr_array_new_with_free_func(g_free));
-    Vector<RefPtr<API::Object> > choosenFiles;
+    Vector<RefPtr<API::Object> > chosenFiles;
     for (int i = 0; files[i]; i++) {
         GRefPtr<GFile> filename = adoptGRef(g_file_new_for_path(files[i]));
 
@@ -307,7 +307,7 @@
         // string, with the 'file://' prefix) to WebCore otherwise the
         // FileChooser won't actually choose it.
         GUniquePtr<char> uri(g_file_get_uri(filename.get()));
-        choosenFiles.append(API::URL::create(String::fromUTF8(uri.get())));
+        chosenFiles.append(API::URL::create(String::fromUTF8(uri.get())));
 
         // Do not use the URI here because this won't reach WebCore.
         g_ptr_array_add(selectedFiles.get(), g_strdup(files[i]));
@@ -315,7 +315,7 @@
     g_ptr_array_add(selectedFiles.get(), 0);
 
     // Select the files in WebCore and update local private attributes.
-    request->priv->listener->chooseFiles(API::Array::create(WTFMove(choosenFiles)).ptr());
+    request->priv->listener->chooseFiles(API::Array::create(WTFMove(chosenFiles)).ptr());
     request->priv->selectedFiles = selectedFiles;
     request->priv->handledRequest = true;
 }

Modified: trunk/Source/WebKit2/UIProcess/API/gtk/WebKitUserMediaPermissionRequest.cpp (198526 => 198527)


--- trunk/Source/WebKit2/UIProcess/API/gtk/WebKitUserMediaPermissionRequest.cpp	2016-03-22 13:22:37 UTC (rev 198526)
+++ trunk/Source/WebKit2/UIProcess/API/gtk/WebKitUserMediaPermissionRequest.cpp	2016-03-22 13:47:30 UTC (rev 198527)
@@ -160,26 +160,26 @@
     /**
      * WebKitUserPermissionRequest:is-for-audio-device:
      *
      * Wether the media device to which the permission was requested has a microphone or not.
      *
      * Since: 2.8
      */
     g_object_class_install_property(objectClass, PROP_IS_FOR_AUDIO_DEVICE,
         g_param_spec_boolean("is-for-audio-device", _("Is for audio device"),
-            _("Wether the media device to which the permission was requested has a microphone or not."),
+            _("Whether the media device to which the permission was requested has a microphone or not."),
             FALSE,
             WEBKIT_PARAM_READABLE));
 
     /**
      * WebKitUserPermissionRequest:is-for-video-device:
      *
      * Wether the media device to which the permission was requested has a video capture capability or not.
      *
      * Since: 2.8
      */
     g_object_class_install_property(objectClass, PROP_IS_FOR_VIDEO_DEVICE,
         g_param_spec_boolean("is-for-video-device", _("Is for video device"),
-            _("Wether the media device to which the permission was requested has a video capture capability or not."),
+            _("Whether the media device to which the permission was requested has a video capture capability or not."),
             FALSE,
             WEBKIT_PARAM_READABLE));
 }
@@ -160,26 +160,26 @@
      * WebKitUserPermissionRequest:is-for-audio-device:
      *
-     * Wether the media device to which the permission was requested has a microphone or not.
+     * Whether the media device to which the permission was requested has a microphone or not.
      *
      * Since: 2.8
@@ -160,26 +160,26 @@
      * WebKitUserPermissionRequest:is-for-video-device:
      *
-     * Wether the media device to which the permission was requested has a video capture capability or not.
+     * Whether the media device to which the permission was requested has a video capture capability or not.
      *
      * Since: 2.8
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to